/* $Id: rmat3supp.cpp,v 1.7 2006/01/18 12:02:28 cvsroot Exp $ */

/* GenLib2 - General Library 2
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <cstring>
#include "rmat3supp.h"

namespace GenLib2
{

// type of rotation parameters

ERotMatrix3::map_t ERotMatrix3::_map[] =
{
	{ UNDEFINED,			"undef",				"undefined",			0 },
	{ ROTATION_MATRIX,		"rotation-matrix",		"rotation matrix",		9 },
	{ DIRECTION_COSINES,	"direction-cosines",	"direction cosines",	9 },
	{ ANGLES_OPK_FIX,		"angles-opk-fix",		"angles, omega-phi-kappa, fixed axes, cw",		3 },
	{ ANGLES_OPK_FIX_CCW,	"angles-opk-fix-ccw",	"angles, omega-phi-kappa, fixed axes, ccw",	3 },
	{ ANGLES_POK_FIX,		"angles-pok-fix",		"angles, phi-omega-kappa, fixed axes, ccw",	3 },
	{ ANGLES_OPK_ROT,		"angles-opk-rot",		"angles, omega-phi-kappa, rotated axes, ccw",	3 },
	{ ANGLES_POK_ROT,		"angles-pok-rot",		"angles, phi-omega-kappa, rotated axes, ccw",	3 },
	{ ANGLES_AUSTRALIS,		"angles-australis",		"angles australis parameters",		3 },
	{ ANGLES_SMALL,			"small-angles",			"small angles",			3 },
	{ UPPER_DIAG_ELEM,		"upper-diag-elem",		"upper diagonal elements",		3 },
	{ RODRIGUES_MATRIX,		"rodrigues-matrix",		"rodrigues matrix",		3 },
	{ UNIT_QUATERNION, 		"unit-quaternion",		"unit quaternion",		4 },
	{ ROTATION_ABOUT_LINE, 	"rotation-about-line",	"one rotation about a line",		4 },
	{ END_OF_MAP, 			0, 0, 0 }
};


// get rotation parameter name

const char* ERotMatrix3::name(int code)
{
	for (int i = 0; _map[i].keyword != 0; i++)
		{
		if (_map[i].code == code)
			return _map[i].name;
		}

	return _map[0].name;
}


// get rotation parameter enumerator

ERotMatrix3::ecode ERotMatrix3::code(const char* key)
{
	for (int i = 0; _map[i].keyword != 0; i++)
		{
		if (strcmp(key, _map[i].keyword) == 0)
			return (ecode)_map[i].code;
		}

	return (ecode)_map[0].code;
}


// get number of rotation parameters

size_t ERotMatrix3::size(int code)
{
	for (int i = 0; _map[i].keyword != 0; i++)
		{
		if (_map[i].code == code)
			return _map[i].size;
		}

	return _map[0].size;
}


// print map

void ERotMatrix3::print(ostream& os) const
{
	os << "code/keyword/name/size\n";
	for (int i = 0; _map[i].keyword != 0; i++)
		{
		os << _map[i].code << "/" << _map[i].keyword << "/"
			<< _map[i].name << "/" << _map[i].size << endl;
		}
}


// get number of map items

size_t ERotMatrix3::map_size() const
{
	size_t i = 0;
	while (_map[i].keyword != 0)
		i++;
	return --i;
}

} // namespace GenLib2

